Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| AUTO POSTO CAMOBI LTDA
CNPJ: 03.678.545/0001-40 Inscrição Estadual: 1090259899
EST RSC 287, 6880, CAMOBI, SANTA MARIA, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 45851 Série: 2 Data de Emissão: 10/10/2019 13:26:20
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 1003 6785 4500 0140 6500 2000 0458 5118 8785 6194
Protocolo de Autorização: 143191392104002
CONSUMIDOR
Consumidor não identificado
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
2 | GASOLINA ADITIVADA | 39,25 | LT | 4,599 | 180,51
Valor total R$ | 180,51
Valor descontos R$ | 0,00
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:43